TrustedTimeWebPlugin constructor
TrustedTimeWebPlugin()
Creates the web plugin instance.
This constructor is provided for completeness but instances are not typically created directly; instead, use registerWith to set up the plugin with the Flutter engine.
Implementation
TrustedTimeWebPlugin();